@@ -7,6 +7,8 @@ pub mod control;
 pub mod memory;
 pub mod numeric;
 pub mod parametric;
+pub mod reference;
+pub mod table;
 pub mod variable;
 
 pub struct Local {
