@@ -6,8 +6,8 @@ pub use code::{Body, Instruction, Local};
 mod data;
 pub use data::{Data, DataMode};
 
-mod element;
-pub use element::{Element, ElementMode};
+mod elements;
+pub use elements::{Element, ElementMode};
 
 mod exports;
 pub use exports::{Export, ExportDescription};
